import 'package:flutter/material.dart';
import 'package:firebase_database/firebase_database.dart';
import 'package:shared_preferences/shared_preferences.dart';
// 기타 import...

import '../../dialogs/settings_dialog.dart';
import 'create_room_page.dart';
import 'room_search_home_page.dart';

// 진행중 방
import 'playing_private_page.dart';
import 'playing_team_page.dart';

// 임시: 서버 API & 모달
import '../../plugins/api.dart';
import '../../dialogs/response_dialog.dart';

// 뒤로가기
import 'package:fluttertoast/fluttertoast.dart'; // 뒤로가기 안내 문구에 Toast 등 사용

// 설정
import '../../config/config.dart';

// 설문조사
import '../../dialogs/survey_dialog.dart';

// 광고
import '../../plugins/admob.dart';

class MainPage extends StatefulWidget {
  const MainPage({Key? key}) : super(key: key);

  @override
  _MainPageState createState() => _MainPageState();
}

class _MainPageState extends State<MainPage> {
  // 뒤로가기 처리
  DateTime? _lastPressedTime;

  // 예: 2초 이내로 뒤로가기를 한 번 더 누르면 종료
  static const _exitDuration = Duration(seconds: 2);

  @override
  void initState() {
    super.initState();

    // (A) 메인페이지 들어올 때 전체 FRD 연결 해제
    FirebaseDatabase.instance.goOffline();

    // (B) 랜딩 페이지 정보 확인
    WidgetsBinding.instance.addPostFrameCallback((_) {
      _checkLandingMainPageInfo();
    });
  }

  @override
  void dispose() {
    super.dispose();
  }

  Future<bool> _onWillPop() async {
    final now = DateTime.now();
    if (_lastPressedTime == null ||
        now.difference(_lastPressedTime!) > _exitDuration) {
      // 첫 번째 뒤로가기 누름 or 이전 누름이 오래 전
      _lastPressedTime = now;

      // 안내 문구 띄우기 (Toast 예시)
      Fluttertoast.showToast(
        msg: '한 번 더 누르면 앱이 종료됩니다.',
        toastLength: Toast.LENGTH_SHORT,
        gravity: ToastGravity.BOTTOM,
      );
      return false; // 페이지 pop 하지 않음
    }
    // 2초 이내에 뒤로가기 두 번째 누름 → 앱 종료 허용
    return true; // pop 허용 (Scaffold 밖으로 벗어남, 결과적으로 앱 종료)
  }

  /// (B) 서버에 "강제 종료 여부" 확인 → 방이 있으면 재입장
  Future<void> _checkLandingMainPageInfo() async {
    try {
      final Map<String, dynamic> requestBody = {};
      final response = await Api.serverRequest(
        uri: '/room/score/landing/mainpage/info',
        body: requestBody,
      );

      if (response['result'] == 'OK') {
        final resp = response['response'] ?? {};
        if (resp['result'] == 'OK') {
          final data = resp['data'] ?? {};
          final forceExitYn = (data['force_exit_yn'] ?? 'N').toString().toUpperCase();
          if (forceExitYn == 'Y') {
            final int roomSeq       = data['room_seq'] ?? 0;
            final String roomType   = (data['room_type_name'] ?? '').toString().toUpperCase();
            final String roomTitle  = (data['room_title'] ?? '').toString();

            // (1) 재입장 전 FRD 연결 복원
            FirebaseDatabase.instance.goOnline();

            showResponseDialog(context, '게임 재입장', '강제 종료 된 게임에 재입장 합니다.');

            // (2) 방 타입에 따라 pushReplacement
            if (roomType == 'TEAM') {
              Navigator.pushReplacement(
                context,
                MaterialPageRoute(
                  builder: (_) => PlayingTeamPage(
                    roomSeq: roomSeq,
                    roomTitle: roomTitle.isNotEmpty ? roomTitle : '재입장 (팀전)',
                  ),
                ),
              );
            } else {
              // 개인전
              Navigator.pushReplacement(
                context,
                MaterialPageRoute(
                  builder: (_) => PlayingPrivatePage(
                    roomSeq: roomSeq,
                    roomTitle: roomTitle.isNotEmpty ? roomTitle : '재입장 (개인전)',
                  ),
                ),
              );
            }
          }
          final surveyYn = (data['survey_yn'] ?? 'N').toString().toUpperCase();
          final joinGameYn = (data['join_game_yn'] ?? 'N').toString().toUpperCase();
          final prefs = await SharedPreferences.getInstance();
          final surveyShownToday = prefs.getString('survey_popup_today') ?? 'N';
          final nickname = (data['nickname'] ?? '').toString();
          if (surveyYn == 'N' && joinGameYn == 'Y' && surveyShownToday == 'N') {
            // 설문조사 팝업 표시
            Future.delayed(Duration.zero, () {
              showSurveyDialog(context, nickname);
            });
          }
        } else {
          final msgTitle = resp['response_info']?['msg_title'] ?? '오류';
          final msgContent = resp['response_info']?['msg_content'] ?? '강제 종료 여부 확인 실패';
          showResponseDialog(context, msgTitle, msgContent);
        }
      } else {
        showResponseDialog(context, '서버 오류', '강제 종료 여부 확인에 실패했습니다.');
      }
    } catch (e) {
      showResponseDialog(context, '서버 오류', '강제 종료 여부 확인에 실패했습니다.');
    }
  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      onWillPop: _onWillPop,
      child: Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(
        backgroundColor: Colors.black,
        elevation: 0,
        automaticallyImplyLeading: false, // 뒤로가기 버튼 X
        title: const Text(
          'ALLSCORE',
          style: TextStyle(color: Colors.white),
        ),
        actions: [
          IconButton(
            icon: const Icon(Icons.settings, color: Colors.white),
            onPressed: () {
              showSettingsDialog(context);
            },
          ),
        ],
      ),
      
      bottomNavigationBar: AdBannerWidget(),

      body: Column(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          // 중앙 버튼
          Expanded(
            child: Padding(
              padding: const EdgeInsets.all(16.0),
              child: Center(
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: [
                    _buildBlackWhiteButton(
                      label: '방만들기',
                      onTap: () {
                        Navigator.push(
                          context,
                          MaterialPageRoute(builder: (_) => const CreateRoomPage()),
                        );
                      },
                    ),
                    const SizedBox(width: 16),
                    _buildBlackWhiteButton(
                      label: '참여하기',
                      onTap: () {
                        Navigator.push(
                          context,
                          MaterialPageRoute(builder: (_) => const RoomSearchHomePage()),
                        );
                      },
                    ),
                  ],
                ),
              ),
            ),
          ),
          ],
        ),
      ),
    );
  }

  Widget _buildBlackWhiteButton({
    required String label,
    required VoidCallback onTap,
  }) {
    return ElevatedButton(
      onPressed: onTap,
      style: ElevatedButton.styleFrom(
        backgroundColor: Colors.white,
        foregroundColor: Colors.black,
        side: const BorderSide(color: Colors.black, width: 1),
        padding: const EdgeInsets.symmetric(vertical: 36, horizontal: 32),
        shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(20)),
      ),
      child: Text(label, style: const TextStyle(color: Colors.black)),
    );
  }
}
